@@ -25,7 +25,7 @@ examples <- function(do.png=FALSE) {
   }
   if(is.character(do.png)) dev.off()
   # at the end we attempt to restore the old par() (active as of the first call of thermo.plot.new)
-  par(thermo$opar)
+  par(get("thermo")$opar)
   cat("Time elapsed: ", proc.time() - .ptime, "\n")
 }
 
