@@ -9,7 +9,7 @@
 info.text <- function(ispecies) {
   # a textual description of species name, formula, source, e.g.
   # CO2 [CO2(aq)] (SSW01, SHS89, 11.Oct.07)
-  this <- thermo$obigt[ispecies, ]
+  this <- get("thermo")$obigt[ispecies, ]
   sourcetext <- this$ref1
   ref2 <- this$ref2
   if(!is.na(ref2)) sourcetext <- paste(sourcetext, ref2, sep=", ")
@@ -24,6 +24,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
   # thermo$obigt$[species|abbrv|formula] or NA otherwise
   # a match to thermo$obigt$state is also required if 'state' is not NULL
   # (first occurence of a match to species is returned otherwise)
+  thermo <- get("thermo")
   # all matches for the species
   matches.species <- thermo$obigt$name==species | 
     thermo$obigt$abbrv==species | thermo$obigt$formula==species
@@ -49,6 +50,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
         eos <- aa2eos(aa, state)
         # the real assignment work 
         nrows <- suppressMessages(mod.obigt(eos))
+        thermo <- get("thermo", "CHNOSZ")
         matches.species <- rep(FALSE, nrows)
         matches.species[nrows] <- TRUE
       } else return(NA)
@@ -59,7 +61,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
     # special treatment for H2O: aq retrieves the liq
     if(species %in% c("H2O", "water") & state=="aq") state <- "liq"
     # the matches for both species and state
-    matches.state <- matches.species & grepl(state, thermo$obigt$state)
+    matches.state <- matches.species & grepl(state, get("thermo")$obigt$state)
     if(!any(matches.state)) {
       # the requested state is not available for this species
       available.states <- thermo$obigt$state[matches.species]
@@ -95,6 +97,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
 info.numeric <- function(ispecies, check.it=TRUE) {
   # from a numeric species index in 'ispecies' return the 
   # thermodynamic properties and equations-of-state parameters
+  thermo <- get("thermo")
   # if we're called with NA, return an empty row
   if(is.na(ispecies)) {
     this <- thermo$obigt[1,]
@@ -148,6 +151,7 @@ info.approx <- function(species, state=NULL) {
   # returns species indices that have an approximate match of 'species'
   # to thermo$obigt$[name|abbrv|formula], 
   # possibly restricted to a given state
+  thermo <- get("thermo")
   if(!is.null(state)) this <- thermo$obigt[thermo$obigt$state==state, ]
   else this <- thermo$obigt
   # only look for fairly close matches
@@ -179,6 +183,7 @@ info.approx <- function(species, state=NULL) {
 info <- function(species=NULL, state=NULL, check.it=TRUE) {
   ## return information for one or more species in thermo$obigt
   ## if no species are requested, summarize the available data  20101129
+  thermo <- get("thermo")
   if(is.null(species)) {
     msgout("info: 'species' is NULL; summarizing information about thermodynamic data...\n")
     msgout(paste("thermo$obigt has", nrow(thermo$obigt[thermo$obigt$state=="aq", ]), "aqueous,",
